`xotl.tools.future.functools`:mod: - Higher-order functions and callable objects
================================================================================

.. module:: xotl.tools.future.functools

.. testsetup::

   from functools import partial
   from xotl.tools.future.functools import *


.. autofunction:: power(*funcs, times)

.. autoclass:: lwraps(f, n, *, name=None, doc=None, wrapped=None)

.. autofunction:: curry
